/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIFontCatalogService.idl
 */

#ifndef __gen_nsIFontCatalogService_h__
#define __gen_nsIFontCatalogService_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIArray_h__
#include "nsIArray.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIFontCatalogEntry */
#define NS_IFONTCATALOGENTRY_IID_STR "70406f93-5b53-49a0-b5a7-ebf533bfe59b"

#define NS_IFONTCATALOGENTRY_IID \
  {0x70406f93, 0x5b53, 0x49a0, \
    { 0xb5, 0xa7, 0xeb, 0xf5, 0x33, 0xbf, 0xe5, 0x9b }}

class NS_NO_VTABLE nsIFontCatalogEntry : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IFONTCATALOGENTRY_IID)

  enum { FONT_CATALOG_TRUETYPE = 1 };

  /* readonly attribute unsigned short fontCatalogType; */
  NS_IMETHOD GetFontCatalogType(PRUint16 *aFontCatalogType) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIFONTCATALOGENTRY \
  NS_IMETHOD GetFontCatalogType(PRUint16 *aFontCatalogType); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIFONTCATALOGENTRY(_to) \
  NS_IMETHOD GetFontCatalogType(PRUint16 *aFontCatalogType) { return _to GetFontCatalogType(aFontCatalogType); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIFONTCATALOGENTRY(_to) \
  NS_IMETHOD GetFontCatalogType(PRUint16 *aFontCatalogType) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFontCatalogType(aFontCatalogType); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsFontCatalogEntry : public nsIFontCatalogEntry
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIFONTCATALOGENTRY

  nsFontCatalogEntry();

private:
  ~nsFontCatalogEntry();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsFontCatalogEntry, nsIFontCatalogEntry)

nsFontCatalogEntry::nsFontCatalogEntry()
{
  /* member initializers and constructor code */
}

nsFontCatalogEntry::~nsFontCatalogEntry()
{
  /* destructor code */
}

/* readonly attribute unsigned short fontCatalogType; */
NS_IMETHODIMP nsFontCatalogEntry::GetFontCatalogType(PRUint16 *aFontCatalogType)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsITrueTypeFontCatalogEntry */
#define NS_ITRUETYPEFONTCATALOGENTRY_IID_STR "11f3efad-316e-4982-b9cf-9c304b0d5237"

#define NS_ITRUETYPEFONTCATALOGENTRY_IID \
  {0x11f3efad, 0x316e, 0x4982, \
    { 0xb9, 0xcf, 0x9c, 0x30, 0x4b, 0x0d, 0x52, 0x37 }}

class NS_NO_VTABLE nsITrueTypeFontCatalogEntry : public nsIFontCatalogEntry {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_ITRUETYPEFONTCATALOGENTRY_IID)

  /* readonly attribute ACString fileName; */
  NS_IMETHOD GetFileName(nsACString & aFileName) = 0;

  /* readonly attribute ACString familyName; */
  NS_IMETHOD GetFamilyName(nsACString & aFamilyName) = 0;

  /* readonly attribute ACString styleName; */
  NS_IMETHOD GetStyleName(nsACString & aStyleName) = 0;

  /* readonly attribute ACString vendorID; */
  NS_IMETHOD GetVendorID(nsACString & aVendorID) = 0;

  /* readonly attribute short faceIndex; */
  NS_IMETHOD GetFaceIndex(PRInt16 *aFaceIndex) = 0;

  /* readonly attribute short numFaces; */
  NS_IMETHOD GetNumFaces(PRInt16 *aNumFaces) = 0;

  /* readonly attribute short numEmbeddedBitmaps; */
  NS_IMETHOD GetNumEmbeddedBitmaps(PRInt16 *aNumEmbeddedBitmaps) = 0;

  /* readonly attribute long numGlyphs; */
  NS_IMETHOD GetNumGlyphs(PRInt32 *aNumGlyphs) = 0;

  /* readonly attribute long numUsableGlyphs; */
  NS_IMETHOD GetNumUsableGlyphs(PRInt32 *aNumUsableGlyphs) = 0;

  /* readonly attribute unsigned short weight; */
  NS_IMETHOD GetWeight(PRUint16 *aWeight) = 0;

  /* readonly attribute unsigned short width; */
  NS_IMETHOD GetWidth(PRUint16 *aWidth) = 0;

  /* readonly attribute unsigned long flags; */
  NS_IMETHOD GetFlags(PRUint32 *aFlags) = 0;

  /* readonly attribute long long faceFlags; */
  NS_IMETHOD GetFaceFlags(PRInt64 *aFaceFlags) = 0;

  /* readonly attribute long long styleFlags; */
  NS_IMETHOD GetStyleFlags(PRInt64 *aStyleFlags) = 0;

  /* readonly attribute unsigned long codePageRange1; */
  NS_IMETHOD GetCodePageRange1(PRUint32 *aCodePageRange1) = 0;

  /* readonly attribute unsigned long codePageRange2; */
  NS_IMETHOD GetCodePageRange2(PRUint32 *aCodePageRange2) = 0;

  /* readonly attribute long long fileModTime; */
  NS_IMETHOD GetFileModTime(PRInt64 *aFileModTime) = 0;

  /* void getCCMap (out unsigned long size, [array, size_is (size), retval] out unsigned short ccMaps); */
  NS_IMETHOD GetCCMap(PRUint32 *size, PRUint16 **ccMaps) = 0;

  /* void getEmbeddedBitmapHeights (out unsigned long size, [array, size_is (size), retval] out long heights); */
  NS_IMETHOD GetEmbeddedBitmapHeights(PRUint32 *size, PRInt32 **heights) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSITRUETYPEFONTCATALOGENTRY \
  NS_IMETHOD GetFileName(nsACString & aFileName); \
  NS_IMETHOD GetFamilyName(nsACString & aFamilyName); \
  NS_IMETHOD GetStyleName(nsACString & aStyleName); \
  NS_IMETHOD GetVendorID(nsACString & aVendorID); \
  NS_IMETHOD GetFaceIndex(PRInt16 *aFaceIndex); \
  NS_IMETHOD GetNumFaces(PRInt16 *aNumFaces); \
  NS_IMETHOD GetNumEmbeddedBitmaps(PRInt16 *aNumEmbeddedBitmaps); \
  NS_IMETHOD GetNumGlyphs(PRInt32 *aNumGlyphs); \
  NS_IMETHOD GetNumUsableGlyphs(PRInt32 *aNumUsableGlyphs); \
  NS_IMETHOD GetWeight(PRUint16 *aWeight); \
  NS_IMETHOD GetWidth(PRUint16 *aWidth); \
  NS_IMETHOD GetFlags(PRUint32 *aFlags); \
  NS_IMETHOD GetFaceFlags(PRInt64 *aFaceFlags); \
  NS_IMETHOD GetStyleFlags(PRInt64 *aStyleFlags); \
  NS_IMETHOD GetCodePageRange1(PRUint32 *aCodePageRange1); \
  NS_IMETHOD GetCodePageRange2(PRUint32 *aCodePageRange2); \
  NS_IMETHOD GetFileModTime(PRInt64 *aFileModTime); \
  NS_IMETHOD GetCCMap(PRUint32 *size, PRUint16 **ccMaps); \
  NS_IMETHOD GetEmbeddedBitmapHeights(PRUint32 *size, PRInt32 **heights); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSITRUETYPEFONTCATALOGENTRY(_to) \
  NS_IMETHOD GetFileName(nsACString & aFileName) { return _to GetFileName(aFileName); } \
  NS_IMETHOD GetFamilyName(nsACString & aFamilyName) { return _to GetFamilyName(aFamilyName); } \
  NS_IMETHOD GetStyleName(nsACString & aStyleName) { return _to GetStyleName(aStyleName); } \
  NS_IMETHOD GetVendorID(nsACString & aVendorID) { return _to GetVendorID(aVendorID); } \
  NS_IMETHOD GetFaceIndex(PRInt16 *aFaceIndex) { return _to GetFaceIndex(aFaceIndex); } \
  NS_IMETHOD GetNumFaces(PRInt16 *aNumFaces) { return _to GetNumFaces(aNumFaces); } \
  NS_IMETHOD GetNumEmbeddedBitmaps(PRInt16 *aNumEmbeddedBitmaps) { return _to GetNumEmbeddedBitmaps(aNumEmbeddedBitmaps); } \
  NS_IMETHOD GetNumGlyphs(PRInt32 *aNumGlyphs) { return _to GetNumGlyphs(aNumGlyphs); } \
  NS_IMETHOD GetNumUsableGlyphs(PRInt32 *aNumUsableGlyphs) { return _to GetNumUsableGlyphs(aNumUsableGlyphs); } \
  NS_IMETHOD GetWeight(PRUint16 *aWeight) { return _to GetWeight(aWeight); } \
  NS_IMETHOD GetWidth(PRUint16 *aWidth) { return _to GetWidth(aWidth); } \
  NS_IMETHOD GetFlags(PRUint32 *aFlags) { return _to GetFlags(aFlags); } \
  NS_IMETHOD GetFaceFlags(PRInt64 *aFaceFlags) { return _to GetFaceFlags(aFaceFlags); } \
  NS_IMETHOD GetStyleFlags(PRInt64 *aStyleFlags) { return _to GetStyleFlags(aStyleFlags); } \
  NS_IMETHOD GetCodePageRange1(PRUint32 *aCodePageRange1) { return _to GetCodePageRange1(aCodePageRange1); } \
  NS_IMETHOD GetCodePageRange2(PRUint32 *aCodePageRange2) { return _to GetCodePageRange2(aCodePageRange2); } \
  NS_IMETHOD GetFileModTime(PRInt64 *aFileModTime) { return _to GetFileModTime(aFileModTime); } \
  NS_IMETHOD GetCCMap(PRUint32 *size, PRUint16 **ccMaps) { return _to GetCCMap(size, ccMaps); } \
  NS_IMETHOD GetEmbeddedBitmapHeights(PRUint32 *size, PRInt32 **heights) { return _to GetEmbeddedBitmapHeights(size, heights); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSITRUETYPEFONTCATALOGENTRY(_to) \
  NS_IMETHOD GetFileName(nsACString & aFileName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFileName(aFileName); } \
  NS_IMETHOD GetFamilyName(nsACString & aFamilyName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFamilyName(aFamilyName); } \
  NS_IMETHOD GetStyleName(nsACString & aStyleName) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStyleName(aStyleName); } \
  NS_IMETHOD GetVendorID(nsACString & aVendorID) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetVendorID(aVendorID); } \
  NS_IMETHOD GetFaceIndex(PRInt16 *aFaceIndex) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFaceIndex(aFaceIndex); } \
  NS_IMETHOD GetNumFaces(PRInt16 *aNumFaces) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumFaces(aNumFaces); } \
  NS_IMETHOD GetNumEmbeddedBitmaps(PRInt16 *aNumEmbeddedBitmaps) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumEmbeddedBitmaps(aNumEmbeddedBitmaps); } \
  NS_IMETHOD GetNumGlyphs(PRInt32 *aNumGlyphs) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumGlyphs(aNumGlyphs); } \
  NS_IMETHOD GetNumUsableGlyphs(PRInt32 *aNumUsableGlyphs) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetNumUsableGlyphs(aNumUsableGlyphs); } \
  NS_IMETHOD GetWeight(PRUint16 *aWeight) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetWeight(aWeight); } \
  NS_IMETHOD GetWidth(PRUint16 *aWidth) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetWidth(aWidth); } \
  NS_IMETHOD GetFlags(PRUint32 *aFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFlags(aFlags); } \
  NS_IMETHOD GetFaceFlags(PRInt64 *aFaceFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFaceFlags(aFaceFlags); } \
  NS_IMETHOD GetStyleFlags(PRInt64 *aStyleFlags) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetStyleFlags(aStyleFlags); } \
  NS_IMETHOD GetCodePageRange1(PRUint32 *aCodePageRange1) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCodePageRange1(aCodePageRange1); } \
  NS_IMETHOD GetCodePageRange2(PRUint32 *aCodePageRange2) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCodePageRange2(aCodePageRange2); } \
  NS_IMETHOD GetFileModTime(PRInt64 *aFileModTime) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFileModTime(aFileModTime); } \
  NS_IMETHOD GetCCMap(PRUint32 *size, PRUint16 **ccMaps) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetCCMap(size, ccMaps); } \
  NS_IMETHOD GetEmbeddedBitmapHeights(PRUint32 *size, PRInt32 **heights) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetEmbeddedBitmapHeights(size, heights); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsTrueTypeFontCatalogEntry : public nsITrueTypeFontCatalogEntry
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSITRUETYPEFONTCATALOGENTRY

  nsTrueTypeFontCatalogEntry();

private:
  ~nsTrueTypeFontCatalogEntry();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsTrueTypeFontCatalogEntry, nsITrueTypeFontCatalogEntry)

nsTrueTypeFontCatalogEntry::nsTrueTypeFontCatalogEntry()
{
  /* member initializers and constructor code */
}

nsTrueTypeFontCatalogEntry::~nsTrueTypeFontCatalogEntry()
{
  /* destructor code */
}

/* readonly attribute ACString fileName; */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetFileName(nsACString & aFileName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute ACString familyName; */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetFamilyName(nsACString & aFamilyName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute ACString styleName; */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetStyleName(nsACString & aStyleName)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute ACString vendorID; */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetVendorID(nsACString & aVendorID)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute short faceIndex; */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetFaceIndex(PRInt16 *aFaceIndex)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute short numFaces; */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetNumFaces(PRInt16 *aNumFaces)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute short numEmbeddedBitmaps; */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetNumEmbeddedBitmaps(PRInt16 *aNumEmbeddedBitmaps)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long numGlyphs; */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetNumGlyphs(PRInt32 *aNumGlyphs)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long numUsableGlyphs; */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetNumUsableGlyphs(PRInt32 *aNumUsableGlyphs)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute unsigned short weight; */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetWeight(PRUint16 *aWeight)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute unsigned short width; */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetWidth(PRUint16 *aWidth)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute unsigned long flags; */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetFlags(PRUint32 *aFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long long faceFlags; */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetFaceFlags(PRInt64 *aFaceFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long long styleFlags; */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetStyleFlags(PRInt64 *aStyleFlags)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute unsigned long codePageRange1; */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetCodePageRange1(PRUint32 *aCodePageRange1)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute unsigned long codePageRange2; */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetCodePageRange2(PRUint32 *aCodePageRange2)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute long long fileModTime; */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetFileModTime(PRInt64 *aFileModTime)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getCCMap (out unsigned long size, [array, size_is (size), retval] out unsigned short ccMaps); */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetCCMap(PRUint32 *size, PRUint16 **ccMaps)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void getEmbeddedBitmapHeights (out unsigned long size, [array, size_is (size), retval] out long heights); */
NS_IMETHODIMP nsTrueTypeFontCatalogEntry::GetEmbeddedBitmapHeights(PRUint32 *size, PRInt32 **heights)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


/* starting interface:    nsIFontCatalogService */
#define NS_IFONTCATALOGSERVICE_IID_STR "a3057187-c40f-4ffa-9160-2b16482053b1"

#define NS_IFONTCATALOGSERVICE_IID \
  {0xa3057187, 0xc40f, 0x4ffa, \
    { 0x91, 0x60, 0x2b, 0x16, 0x48, 0x20, 0x53, 0xb1 }}

class NS_NO_VTABLE nsIFontCatalogService : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IFONTCATALOGSERVICE_IID)

  /* nsIArray getFontCatalogEntries (in ACString familyName, in ACString language, in unsigned short weight, in unsigned short width, in unsigned short slant, in unsigned short spacing); */
  NS_IMETHOD GetFontCatalogEntries(const nsACString & familyName, const nsACString & language, PRUint16 weight, PRUint16 width, PRUint16 slant, PRUint16 spacing, nsIArray **_retval) = 0;

  enum { kFCWeightAny = 0U };

  enum { kFCWeightLight = 300U };

  enum { kFCWeightBook = 400U };

  enum { kFCWeightMedium = 400U };

  enum { kFCWeightRegular = 400U };

  enum { kFCWeightDemi = 600U };

  enum { kFCWeightDemibold = 600U };

  enum { kFCWeightBold = 700U };

  enum { kFCWeighBlack = 900U };

  enum { kFCWidthAny = 0U };

  enum { kFCWidthNarrow = 3U };

  enum { kFCWidthSemicondensed = 4U };

  enum { kFCWidthBlock = 5U };

  enum { kFCWidthMedium = 5U };

  enum { kFCWidthNormal = 5U };

  enum { kFCWidthBold = 7U };

  enum { kFCWidthWide = 7U };

  enum { kFCWidthDoubleWide = 9U };

  enum { kFCSlantAny = 0U };

  enum { kFCSlantRoman = 1U };

  enum { kFCSlantItalic = 2U };

  enum { kFCSlantOblique = 3U };

  enum { kFCSlantReverseItalic = 4U };

  enum { kFCSlantReverseOblique = 5U };

  enum { kFCSpacingAny = 0U };

  enum { kFCSpacingMonospace = 1U };

  enum { kFCSpacingProportional = 2U };

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIFONTCATALOGSERVICE \
  NS_IMETHOD GetFontCatalogEntries(const nsACString & familyName, const nsACString & language, PRUint16 weight, PRUint16 width, PRUint16 slant, PRUint16 spacing, nsIArray **_retval); \

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIFONTCATALOGSERVICE(_to) \
  NS_IMETHOD GetFontCatalogEntries(const nsACString & familyName, const nsACString & language, PRUint16 weight, PRUint16 width, PRUint16 slant, PRUint16 spacing, nsIArray **_retval) { return _to GetFontCatalogEntries(familyName, language, weight, width, slant, spacing, _retval); } \

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIFONTCATALOGSERVICE(_to) \
  NS_IMETHOD GetFontCatalogEntries(const nsACString & familyName, const nsACString & language, PRUint16 weight, PRUint16 width, PRUint16 slant, PRUint16 spacing, nsIArray **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetFontCatalogEntries(familyName, language, weight, width, slant, spacing, _retval); } \

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsFontCatalogService : public nsIFontCatalogService
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIFONTCATALOGSERVICE

  nsFontCatalogService();

private:
  ~nsFontCatalogService();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsFontCatalogService, nsIFontCatalogService)

nsFontCatalogService::nsFontCatalogService()
{
  /* member initializers and constructor code */
}

nsFontCatalogService::~nsFontCatalogService()
{
  /* destructor code */
}

/* nsIArray getFontCatalogEntries (in ACString familyName, in ACString language, in unsigned short weight, in unsigned short width, in unsigned short slant, in unsigned short spacing); */
NS_IMETHODIMP nsFontCatalogService::GetFontCatalogEntries(const nsACString & familyName, const nsACString & language, PRUint16 weight, PRUint16 width, PRUint16 slant, PRUint16 spacing, nsIArray **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIFontCatalogService_h__ */
