/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsPIAccessibleDocument.idl
 */

#ifndef __gen_nsPIAccessibleDocument_h__
#define __gen_nsPIAccessibleDocument_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIAccessNode; /* forward declaration */

class nsIDOMNode; /* forward declaration */


/* starting interface:    nsPIAccessibleDocument */
#define NS_PIACCESSIBLEDOCUMENT_IID_STR "f0809603-74e8-4284-8366-b293a5d0b758"

#define NS_PIACCESSIBLEDOCUMENT_IID \
  {0xf0809603, 0x74e8, 0x4284, \
    { 0x83, 0x66, 0xb2, 0x93, 0xa5, 0xd0, 0xb7, 0x58 }}

class NS_NO_VTABLE nsPIAccessibleDocument : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_PIACCESSIBLEDOCUMENT_IID)

  /* [noscript] void invalidateCacheSubtree (in nsIDOMNode aStartNode); */
  NS_IMETHOD InvalidateCacheSubtree(nsIDOMNode *aStartNode) = 0;

  /* [noscript] void cacheAccessNode (in voidPtr aUniqueID, in nsIAccessNode aAccessNode); */
  NS_IMETHOD CacheAccessNode(void * aUniqueID, nsIAccessNode *aAccessNode) = 0;

  /* [noscript] void destroy (); */
  NS_IMETHOD Destroy(void) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSPIACCESSIBLEDOCUMENT \
  NS_IMETHOD InvalidateCacheSubtree(nsIDOMNode *aStartNode); \
  NS_IMETHOD CacheAccessNode(void * aUniqueID, nsIAccessNode *aAccessNode); \
  NS_IMETHOD Destroy(void); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSPIACCESSIBLEDOCUMENT(_to) \
  NS_IMETHOD InvalidateCacheSubtree(nsIDOMNode *aStartNode) { return _to InvalidateCacheSubtree(aStartNode); } \
  NS_IMETHOD CacheAccessNode(void * aUniqueID, nsIAccessNode *aAccessNode) { return _to CacheAccessNode(aUniqueID, aAccessNode); } \
  NS_IMETHOD Destroy(void) { return _to Destroy(); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSPIACCESSIBLEDOCUMENT(_to) \
  NS_IMETHOD InvalidateCacheSubtree(nsIDOMNode *aStartNode) { return !_to ? NS_ERROR_NULL_POINTER : _to->InvalidateCacheSubtree(aStartNode); } \
  NS_IMETHOD CacheAccessNode(void * aUniqueID, nsIAccessNode *aAccessNode) { return !_to ? NS_ERROR_NULL_POINTER : _to->CacheAccessNode(aUniqueID, aAccessNode); } \
  NS_IMETHOD Destroy(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->Destroy(); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public nsPIAccessibleDocument
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSPIACCESSIBLEDOCUMENT

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, nsPIAccessibleDocument)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* [noscript] void invalidateCacheSubtree (in nsIDOMNode aStartNode); */
NS_IMETHODIMP _MYCLASS_::InvalidateCacheSubtree(nsIDOMNode *aStartNode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void cacheAccessNode (in voidPtr aUniqueID, in nsIAccessNode aAccessNode); */
NS_IMETHODIMP _MYCLASS_::CacheAccessNode(void * aUniqueID, nsIAccessNode *aAccessNode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* [noscript] void destroy (); */
NS_IMETHODIMP _MYCLASS_::Destroy()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsPIAccessibleDocument_h__ */
