/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Radha Kulkarni <radha@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or 
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

/**
 * The interface to nsISHentry. Each document or subframe in 
 * Session History will have a nsISHEntry associated with it which will
 * hold all information required to recreate the document from history
 * 
 */
#include "nsISupports.idl"
#include "nsIURI.idl"
#include "nsIInputStream.idl"

interface nsILayoutHistoryState;
interface nsIDOMDocument;

[scriptable, uuid(65281BA1-988A-11d3-BDC7-0050040A9B44)]
interface nsISHEntry : nsISupports 
{

/** URI for the document */
void SetURI(in nsIURI aURI);

/** Referrer URI */
attribute nsIURI referrerURI;

/**  DOM Document */
attribute nsIDOMDocument document;

/** Title for the document */
void SetTitle(in wstring aTitle);

/** Post Data for the document */
attribute nsIInputStream postData;

/** LayoutHistoryState for scroll position and form values */
attribute nsILayoutHistoryState layoutHistoryState;

/** parent of this entry */
attribute nsISHEntry parent;

/**
 * The loadType for this entry. This is typically loadHistory except
 * when reload is pressed, it has the appropriate reload flag
 */
attribute  unsigned long loadType;

/**
 * An ID to help identify this entry from others during
 * subframe navigation
 */
attribute unsigned long ID;

/** attribute to set and get the cache key for the entry */
attribute nsISupports cacheKey;

/** attribute to indicate whether layoutHistoryState should be saved */
attribute boolean saveLayoutStateFlag;

/** attribute to indicate whether the page is already expired in cache */
attribute boolean expirationStatus;

/** attribute to indicate the content-type of the document that this
    is a session history entry for */
attribute ACString contentType; 
 
/** Set/Get scrollers' positon in anchored pages */
void setScrollPosition(in PRInt32 x, in PRInt32 y);
void getScrollPosition(out PRInt32 x, out PRInt32 y);

/** Additional ways to create an entry */
void create(in nsIURI aURI, in wstring aTitle, in nsIDOMDocument aDocument,
            in nsIInputStream aInputStream, in nsILayoutHistoryState aHistoryLayoutState,
            in nsISupports aCacheKey, in ACString aContentType);

nsISHEntry clone();

/** Attribute that indicates if this entry is for a subframe navigation */
void SetIsSubFrame(in boolean aFlag);


};


%{ C++
// {BFD1A791-AD9F-11d3-BDC7-0050040A9B44}
#define NS_SHENTRY_CID \
{0xbfd1a791, 0xad9f, 0x11d3, {0xbd, 0xc7, 0x0, 0x50, 0x4, 0xa, 0x9b, 0x44}}

#define NS_SHENTRY_CONTRACTID \
    "@mozilla.org/browser/session-history-entry;1"

%}

