/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code is Mozilla.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications.  Portions created by Netscape Communications are
 * Copyright (C) 2001 by Netscape Communications.  All
 * Rights Reserved.
 * 
 * Contributor(s): 
 *   Vidur Apparao <vidur@netscape.com> (original author)
 */

#include "nsISupports.idl"

interface nsISchema;
interface nsISchemaType;
interface nsIDOMElement;
interface nsISchemaLoadListener;

[scriptable, uuid(3c14a032-6f4e-11d5-9b46-000064657374)]
interface nsISchemaLoader : nsISupports {
  nsISchema load(in AString schemaURI);
  void loadAsync(in AString schemaURI, 
                 in nsISchemaLoadListener listener);
  nsISchema processSchemaElement(in nsIDOMElement element);
};

[scriptable, function, uuid(3c14a033-6f4e-11d5-9b46-000064657374)]
interface nsISchemaLoadListener : nsISupports {
  void onLoad(in nsISchema schema);
  void onError(in PRInt32 status,
               in AString statusMessage);
};

%{ C++
#define NS_SCHEMALOADER_CID                           \
{ /* 5adc10f0-74e1-11d5-9b49-00104bdf5339 */          \
 0x5adc10f0, 0x74e1, 0x11d5,                          \
{0x9b, 0x49, 0x00, 0x10, 0x4b, 0xdf, 0x53, 0x39}}     

#define NS_SCHEMALOADER_CONTRACTID "@mozilla.org/xmlextras/schemas/schemaloader;1"

#define NS_BUILTINSCHEMACOLLECTION_CID                \
{ /* a83b0823-f10e-4235-9859-88a5abd2ed54 */          \
 0xa83b0823, 0xf10e, 0x4235,                          \
{0x98, 0x59, 0x88, 0xa5, 0xab, 0xd2, 0xed, 0x54}}

#define NS_BUILTINSCHEMACOLLECTION_CONTRACTID "@mozilla.org/xmlextras/schemas/builtinschemacollection;1"

#define NS_ERROR_SCHEMA_NOT_SCHEMA_ELEMENT NS_ERROR_GENERATE_FAILURE(NS_ERROR_MODULE_GENERAL, 1)
#define NS_ERROR_SCHEMA_UNKNOWN_TARGET_NAMESPACE NS_ERROR_GENERATE_FAILURE(NS_ERROR_MODULE_GENERAL, 2)
#define NS_ERROR_SCHEMA_UNKNOWN_TYPE NS_ERROR_GENERATE_FAILURE(NS_ERROR_MODULE_GENERAL, 3)
#define NS_ERROR_SCHEMA_UNKNOWN_PREFIX NS_ERROR_GENERATE_FAILURE(NS_ERROR_MODULE_GENERAL, 4)
#define NS_ERROR_SCHEMA_INVALID_STRUCTURE NS_ERROR_GENERATE_FAILURE(NS_ERROR_MODULE_GENERAL, 5)
#define NS_ERROR_SCHEMA_INVALID_TYPE_USAGE NS_ERROR_GENERATE_FAILURE(NS_ERROR_MODULE_GENERAL, 6)
#define NS_ERROR_SCHEMA_MISSING_TYPE NS_ERROR_GENERATE_FAILURE(NS_ERROR_MODULE_GENERAL, 7)
#define NS_ERROR_SCHEMA_FACET_VALUE_ERROR NS_ERROR_GENERATE_FAILURE(NS_ERROR_MODULE_GENERAL, 8)
#define NS_ERROR_SCHEMA_LOADING_ERROR NS_ERROR_GENERATE_FAILURE(NS_ERROR_MODULE_GENERAL, 9)
%}
