/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is Mozilla code.
 *
 * The Initial Developer of the Original Code is Zero-Knowledge Systems,
 * Inc.  Portions created by Zero-Knowledge are Copyright (C) 2000
 * Zero-Knowledge Systems, Inc.  All Rights Reserved.
 *
 * Contributor(s): 
 */

#include "nsISupports.idl"

interface nsIDOMWindow;
interface nsIURI;

/**
 * Interface for content policy mechanism.  Implementations of this
 * interface can be used to control loading of various types of out-of-line
 * content, or processing of certain types of in-line content.
 */

[scriptable,uuid(1cb4085d-5407-4169-bcfe-4c5ba013fa5b)]
interface nsIContentPolicy : nsISupports
{
  const PRInt32 OTHER       = 0;
  const PRInt32 SCRIPT      = 1;
  const PRInt32 IMAGE       = 2;
  const PRInt32 STYLESHEET  = 3;
  const PRInt32 OBJECT      = 4;
  const PRInt32 SUBDOCUMENT = 5;
  const PRInt32 CONTROL_TAG = 6;
  const PRInt32 RAW_URL     = 7;
  const PRInt32 DOCUMENT    = 8;

  /**
   * Should the content at this location be loaded and processed?
   *
   */
  boolean shouldLoad(in PRInt32 contentType, in nsIURI contentLocation,
                     in nsISupports ctxt, in nsIDOMWindow window);

  /**
   * Should the contents of the element in question be processed?
   */
  boolean shouldProcess(in PRInt32 contentType, in nsIURI documentLocation,
                        in nsISupports ctxt, in nsIDOMWindow window);
};
