/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM ipcIClientQueryHandler.idl
 */

#ifndef __gen_ipcIClientQueryHandler_h__
#define __gen_ipcIClientQueryHandler_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    ipcIClientQueryHandler */
#define IPCICLIENTQUERYHANDLER_IID_STR "6fefea5c-f747-4bb0-972f-2a7b363a01db"

#define IPCICLIENTQUERYHANDLER_IID \
  {0x6fefea5c, 0xf747, 0x4bb0, \
    { 0x97, 0x2f, 0x2a, 0x7b, 0x36, 0x3a, 0x01, 0xdb }}

/**
 * ipcIClientQueryHandler
 *
 * the methods on this interface are called when the result of a client query
 * becomes available.
 */
class NS_NO_VTABLE ipcIClientQueryHandler : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(IPCICLIENTQUERYHANDLER_IID)

  /**
     * called on completion of a client query.
     *
     * @param aQueryID
     *        the return value from one of the "query" methods.
     * @param aStatus
     *        the status of the query.  if this is a failure code, then the
     *        query failed, otherwise the query succeeded.  the value of this
     *        parameter explains the reason for any failure.
     * @param aClientID
     *     ...
     */
  /* void onQueryComplete (in unsigned long aQueryID, in nsresult aStatus, in unsigned long aClientID, [array, size_is (aNameCount)] in string aClientNames, in unsigned long aNameCount, [array, size_is (aTargetCount), const] in nsIDPtr aClientTargets, in unsigned long aTargetCount); */
  NS_IMETHOD OnQueryComplete(PRUint32 aQueryID, nsresult aStatus, PRUint32 aClientID, const char **aClientNames, PRUint32 aNameCount, const nsID * *aClientTargets, PRUint32 aTargetCount) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_IPCICLIENTQUERYHANDLER \
  NS_IMETHOD OnQueryComplete(PRUint32 aQueryID, nsresult aStatus, PRUint32 aClientID, const char **aClientNames, PRUint32 aNameCount, const nsID * *aClientTargets, PRUint32 aTargetCount); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_IPCICLIENTQUERYHANDLER(_to) \
  NS_IMETHOD OnQueryComplete(PRUint32 aQueryID, nsresult aStatus, PRUint32 aClientID, const char **aClientNames, PRUint32 aNameCount, const nsID * *aClientTargets, PRUint32 aTargetCount) { return _to OnQueryComplete(aQueryID, aStatus, aClientID, aClientNames, aNameCount, aClientTargets, aTargetCount); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_IPCICLIENTQUERYHANDLER(_to) \
  NS_IMETHOD OnQueryComplete(PRUint32 aQueryID, nsresult aStatus, PRUint32 aClientID, const char **aClientNames, PRUint32 aNameCount, const nsID * *aClientTargets, PRUint32 aTargetCount) { return !_to ? NS_ERROR_NULL_POINTER : _to->OnQueryComplete(aQueryID, aStatus, aClientID, aClientNames, aNameCount, aClientTargets, aTargetCount); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class _MYCLASS_ : public ipcIClientQueryHandler
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_IPCICLIENTQUERYHANDLER

  _MYCLASS_();

private:
  ~_MYCLASS_();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(_MYCLASS_, ipcIClientQueryHandler)

_MYCLASS_::_MYCLASS_()
{
  /* member initializers and constructor code */
}

_MYCLASS_::~_MYCLASS_()
{
  /* destructor code */
}

/* void onQueryComplete (in unsigned long aQueryID, in nsresult aStatus, in unsigned long aClientID, [array, size_is (aNameCount)] in string aClientNames, in unsigned long aNameCount, [array, size_is (aTargetCount), const] in nsIDPtr aClientTargets, in unsigned long aTargetCount); */
NS_IMETHODIMP _MYCLASS_::OnQueryComplete(PRUint32 aQueryID, nsresult aStatus, PRUint32 aClientID, const char **aClientNames, PRUint32 aNameCount, const nsID * *aClientTargets, PRUint32 aTargetCount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_ipcIClientQueryHandler_h__ */
