/* -*- Mode: IDL; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * The contents of this file are subject to the Netscape Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is Netscape
 * Communications Corporation.  Portions created by Netscape are
 * Copyright (C) 1998 Netscape Communications Corporation. All
 * Rights Reserved.
 *
 * Contributor(s):
 *   John Bandhauer <jband@netscape.com>
 */

/* nsIVariant based Property Bag support. */

#include "nsISupports.idl"
#include "nsIVariant.idl"
#include "nsISimpleEnumerator.idl"

[scriptable, uuid(6dcf9030-a49f-11d5-910d-0010a4e73d9a)]
interface nsIProperty : nsISupports
{
    /**
     * Get the name of the property.
     */
    readonly attribute AString    name;

    /**
     * Get the value of the property.
     */
    readonly attribute nsIVariant value;
};

[scriptable, uuid(bfcd37b0-a49f-11d5-910d-0010a4e73d9a)]
interface nsIPropertyBag : nsISupports
{
    /**
     * Get a nsISimpleEnumerator whose elements are nsIProperty objects.
     */
    readonly attribute nsISimpleEnumerator enumerator;

    /**
     * Get a property value for the given name.
     * @return NS_ERROR_FAILURE if a property with that name doesn't
     * exist.
     */
    nsIVariant getProperty(in AString name);
};

// We can add nsIWritableProperty and nsIWritablePropertyBag when we need them.

