/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is Boris Zbarsky
 * <bzbarsky@mit.edu> Portions created by Boris Zbarsky are Copyright
 * (C) 2001.  All Rights Reserved.
 *
 * Contributor(s):
 */

#include "nsISupports.idl"

interface nsILineInputStream;

[scriptable, uuid(c97b466c-1e6e-4773-a4ab-2b2b3190a7a6)]
interface nsILineInputStream : nsISupports
{
  /**
   * Read a single line from the stream, where a line is a 
   * possibly zero length sequence of 8bit chars terminated by a
   * CR, LF, CRLF, LFCR, or eof.
   * The line terminator is not returned.
   * Return false for end of file, true otherwise
   */
  boolean readLine(out ACString aLine);
};
