/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code is Mozilla.
 * 
 * The Initial Developer of the Original Code is Netscape
 * Communications.  Portions created by Netscape Communications are
 * Copyright (C) 2001 by Netscape Communications.  All
 * Rights Reserved.
 * 
 * Contributor(s): 
 *   Radha Kulkarni(radha@netscape.com)
 */

#include "nsISupports.idl"

interface nsIChannel;

/**
 * An interface to access the the base channel 
 * associated with a MultiPartChannel.
 */

[scriptable, uuid(62d77f66-8ad0-4a7f-91a1-bb048b136490)]
interface nsIMultiPartChannel : nsISupports
{
    /**
     * readonly attribute to access the underlying channel
     */
    readonly attribute nsIChannel baseChannel;

    /**
     * Access to the Content-Disposition header field of this part of
     * a multipart message.  This allows getting the preferred
     * handling method, preferred filename, etc.  See RFC 2183.
     */
    attribute ACString contentDisposition;
};
