/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code is Mozilla Communicator.
 * 
 * The Initial Developer of the Original Code is Netscape Communications
 * Corp.  Portions created by Netscape are Copyright (C) 2000 Netscape 
 * Communications Corp.  All Rights Reserved.
 * 
 * Contributor(s): 
 */

#include "nsISupports.idl"


[scriptable, uuid(f728830e-1dd1-11b2-9598-fb9f414f2465)]
interface nsIScreen : nsISupports
{
  void GetRect ( out long left, out long top, out long width, out long height );
  void GetAvailRect ( out long left, out long top, out long width, out long height );
  
  readonly attribute long pixelDepth;
  readonly attribute long colorDepth;  
};


%{ C++

%}
