/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsIDOMWindowAccess.idl
 */

#ifndef __gen_nsIDOMWindowAccess_h__
#define __gen_nsIDOMWindowAccess_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIDOMWindowAccess */
#define NS_IDOMWINDOWACCESS_IID_STR "7e1ec6ff-2e67-4b26-aa39-a3eb2a3b8a4e"

#define NS_IDOMWINDOWACCESS_IID \
  {0x7e1ec6ff, 0x2e67, 0x4b26, \
    { 0xaa, 0x39, 0xa3, 0xeb, 0x2a, 0x3b, 0x8a, 0x4e }}

/**
 * nsIDOMWindowAccess is intended for giving privileged script access to
 * additional properties and methods of nsIDOMWindow. Access this interface
 * by calling getInterface on a DOMWindow
 */
class NS_NO_VTABLE nsIDOMWindowAccess : public nsISupports {
 public: 

  NS_DEFINE_STATIC_IID_ACCESSOR(NS_IDOMWINDOWACCESS_IID)

  /* void setImageAnimationMode (in unsigned short aMode); */
  NS_IMETHOD SetImageAnimationMode(PRUint16 aMode) = 0;

};

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOMWINDOWACCESS \
  NS_IMETHOD SetImageAnimationMode(PRUint16 aMode); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOMWINDOWACCESS(_to) \
  NS_IMETHOD SetImageAnimationMode(PRUint16 aMode) { return _to SetImageAnimationMode(aMode); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOMWINDOWACCESS(_to) \
  NS_IMETHOD SetImageAnimationMode(PRUint16 aMode) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetImageAnimationMode(aMode); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDOMWindowAccess : public nsIDOMWindowAccess
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOMWINDOWACCESS

  nsDOMWindowAccess();

private:
  ~nsDOMWindowAccess();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDOMWindowAccess, nsIDOMWindowAccess)

nsDOMWindowAccess::nsDOMWindowAccess()
{
  /* member initializers and constructor code */
}

nsDOMWindowAccess::~nsDOMWindowAccess()
{
  /* destructor code */
}

/* void setImageAnimationMode (in unsigned short aMode); */
NS_IMETHODIMP nsDOMWindowAccess::SetImageAnimationMode(PRUint16 aMode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDOMWindowAccess_h__ */
